Improve this Doc

# Error: $compile:badrestrict
Invalid Directive Restrict

    Restrict property '{0}' of directive '{1}' is invalid

## Description

This error occurs when the restrict property of a directive is not valid.

The directive restrict property must be a string including one or more of the following characters:

- E (element)
- A (attribute)
- C (class)
- M (comment)

For example:

    restrict: 'E'
    restrict: 'EAC'